@@ -1,3 +1,19 @@
+-- Copyright (©) 2003-2013 Teus Benschop.
+
+-- This program is free software; you can redistribute it and/or modify
+-- it under the terms of the GNU General Public License as published by
+-- the Free Software Foundation; either version 3 of the License, or
+-- (at your option) any later version.
+
+-- This program is distributed in the hope that it will be useful,
+-- but WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+-- GNU General Public License for more details.
+
+-- You should have received a copy of the GNU General Public License
+-- along with this program; if not, write to the Free Software
+-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
 USE `BIBLEDITDATABASE`;
 
 CREATE TABLE IF NOT EXISTS notes (
@@ -20,6 +36,10 @@ CREATE TABLE IF NOT EXISTS notes (
   FULLTEXT reversedsearch (reversedtext)
 ) engine = MyISAM;
 
+CREATE TABLE IF NOT EXISTS notes_del (
+  note int primary key,
+  days int
+) engine = MyISAM;
 
 DROP PROCEDURE IF EXISTS upgrade_one;
 DELIMITER //
@@ -55,3 +75,19 @@ CALL upgrade_one ();
 DROP PROCEDURE upgrade_one;
 
 
+DROP PROCEDURE IF EXISTS upgrade_two;
+DELIMITER //
+CREATE PROCEDURE upgrade_two () 
+BEGIN
+  SET @version := (SELECT version FROM version WHERE NAME = 'notes');
+  IF @version = 1 THEN 
+    ALTER TABLE notes DROP private;
+    UPDATE version SET version = 2 WHERE name = 'notes';
+  END IF;
+END;
+//
+DELIMITER ;
+CALL upgrade_two ();
+DROP PROCEDURE upgrade_two;
+
+
