@@ -1,17 +1,54 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+ 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 class filterGitTest extends PHPUnit_Framework_TestCase
 {
 
 
+  private $bible;
+  private $repository;
+  private $newrepository;
   private $psalms_0_data;
   private $psalms_11_data;
   private $song_of_solomon_2_data;
 
 
-  private function initialize_data () 
+  protected function setUp () 
   {
+    $this->bible = "PHPUnit";
+    $this->repository = uniqid (sys_get_temp_dir() . "/");
+    $this->newrepository = uniqid (sys_get_temp_dir() . "/");
+
+    $this->tearDown ();
+
+    $database_bibles = Database_Bibles::getInstance();
+    $database_bibles->createBible ($this->bible);
+
+    mkdir ($this->repository);
+    mkdir ($this->newrepository);
+
+    $command = "cd " . $this->repository . "; git init 2>&1";
+    exec ($command, $result, $exit_code);
+    $command = "cd " . $this->newrepository . "; git init 2>&1";
+    exec ($command, $result, $exit_code);
+
 $this->psalms_0_data = <<<EOD
 \\id PSA
 \\h Izihlabelelo
@@ -19,6 +56,7 @@ $this->psalms_0_data = <<<EOD
 \\mt2 UGWALO
 \\mt LWEZIHLABELELO
 EOD;
+
 $this->psalms_11_data = <<<EOD
 \\c 11
 \\s IN\\sc KOSI\\sc* iyisiphephelo sabaqotho
@@ -33,6 +71,7 @@ $this->psalms_11_data = <<<EOD
 \\v 6 Uzanisa phezu kwababi imijibila, umlilo, lesolufa*\\x + Jobe 18.15.\\x*, lomoya otshisayo\\x + Hlab. 119.53. Lilo 5.10.\\x*, kuzakuba yisabelo senkezo yabo\\x + Hlab. 75.8. Jobe 21.20. Hlab. 16.5.\\x*.
 \\v 7 Ngoba ilungile iN\\sc KOSI\\sc*, iyathanda ukulunga\\x + Hlab. 33.5. 45.7. Hlab. 37.28. 146.8.\\x*; ubuso bayo buyabona oqotho\\x + Hlab. 33.18. Hlab. 17.2.\\x*.
 EOD;
+
 $this->song_of_solomon_2_data = <<<EOD
 \\c 2
 \\p
@@ -58,99 +97,179 @@ $this->song_of_solomon_2_data = <<<EOD
 \\v 16 Isithandwa sami ngesami, lami ngingowaso\\x + 6.3. 7.10.\\x*, eselusa phakathi kwemiduze\\x + 2.1. 4.5. 6.3.\\x*.
 \\v 17 Kuze kube semadabukakusa, lamathunzi abaleke\\x + 4.6.\\x*, phenduka, sithandwa sami, ube njengomziki kumbe njengethole lendluzele\\x + 8.14. 2.9.\\x* phezu kwezintaba zeBhetheri\\x + 2 Sam. 2.29.\\x*.
 EOD;
+
+    mkdir ($this->repository . "/Psalms");
+    mkdir ($this->repository . "/Psalms/0");
+    mkdir ($this->repository . "/Psalms/11");
+    mkdir ($this->repository . "/Song of Solomon");
+    mkdir ($this->repository . "/Song of Solomon/2");
+
+
+    file_put_contents ($this->repository . "/Psalms/0/data", $this->psalms_0_data);
+    file_put_contents ($this->repository . "/Psalms/11/data", $this->psalms_11_data);
+    file_put_contents ($this->repository . "/Song of Solomon/2/data", $this->song_of_solomon_2_data);
+
+
     $_SERVER['HTTP_USER_AGENT'] = "PHPUnit";
     $_SERVER['REMOTE_ADDR'] = "127.0.0.1";
     $_SESSION['user'] = "PHPUnit";
-  }
-  
 
-  private function initialize_directories ($directory) 
-  {
-    mkdir ("$directory/Psalms");
-    mkdir ("$directory/Psalms/0");
-    mkdir ("$directory/Psalms/11");
-    mkdir ("$directory/Song of Solomon");
-    mkdir ("$directory/Song of Solomon/2");
   }
 
 
   protected function tearDown ()
   {
+    $database_bibles = Database_Bibles::getInstance();
+    $database_bibles->deleteDiffBible ($this->bible);
+    $database_bibles->deleteBible ($this->bible);
+    Filter_Rmdir::rmdir ($this->repository);
+    Filter_Rmdir::rmdir ($this->newrepository);
   }
 
 
-  /**
-  * This tests round-tripping git Bible data in the file system,
-  * being transferred to the database, then back to the filesystem.
-  */
-  public function testFiledata2database2filedata()
+  public function testSyncBibleToGit1 ()
   {
-    // Working directory.
-    $directory = uniqid (sys_get_temp_dir() . "/");
-    mkdir ($directory);
-
-    // Set up testing data.    
-    $this->initialize_data();
-    $this->initialize_directories ($directory);
-
-    // Simulate the presence of some chapters.
-    file_put_contents ("$directory/Psalms/0/data", $this->psalms_0_data);
-    file_put_contents ("$directory/Psalms/11/data", $this->psalms_11_data);
-    file_put_contents ("$directory/Song of Solomon/2/data", $this->song_of_solomon_2_data);
-
-    // Create a temporal Bible in the database and store some data in it.
-    // Filter_Git, when called with this data, is supposed to erase this data if it is not in the filesystem.
     $database_bibles = Database_Bibles::getInstance();
-    $bible = "PHPUnit";
-    $database_bibles->createBible ($bible);
-    $database_bibles->storeChapter ($bible, 2, 1, $this->song_of_solomon_2_data);
-    $database_bibles->storeChapter ($bible, 3, 4, $this->song_of_solomon_2_data);
-    $database_bibles->storeChapter ($bible, 5, 6, $this->song_of_solomon_2_data);
 
-    // Call the filter for each chapter.
-    Filter_Git::bibleFiledata2database ($directory, $bible, "Exodus/1/data |    2 +-");
-    Filter_Git::bibleFiledata2database ($directory, $bible, "Leviticus/4/data |    2 +-");
-    Filter_Git::bibleFiledata2database ($directory, $bible, "Deuteronomy/6/data |    2 +-");
-    Filter_Git::bibleFiledata2database ($directory, $bible, "Psalms/0/data |    2 +-");
-    Filter_Git::bibleFiledata2database ($directory, $bible, "Psalms/11/data |    2 +-");
-    Filter_Git::bibleFiledata2database ($directory, $bible, "Song of Solomon/2/data |    2 +-");
-
-    $database_bibles = Database_Bibles::getInstance();
+    $repository = $this->repository;
     
-    // Assert database has certain books.
-    $books = $database_bibles->getBooks ($bible);
-    $this->assertEquals(array(19, 22), $books);
+    $this->assertFileExists ("$repository/.git");
+    $this->assertFileExists ("$repository/Psalms/0/data");
+    $this->assertFileExists ("$repository/Psalms/11/data");
+    $this->assertFileExists ("$repository/Song of Solomon/2/data");
+    $this->assertFileNotExists ("$repository/Exodus/1/data");
 
-    // Assert Psalms has certain chapters.
-    $chapters = $database_bibles->getChapters ($bible, 19);
-    $this->assertEquals(array(0, 11), $chapters);
+    $database_bibles->storeChapter ($this->bible, 2, 1, $this->song_of_solomon_2_data);
+    Filter_Git::syncBible2Git ($this->bible, $this->repository);
 
-    // Assert Song of Solomon has a certain chapter.
-    $chapters = $database_bibles->getChapters ($bible, 22);
-    $this->assertEquals(array(2), $chapters);
-
-    // Assert data in Psalm 11.
-    $data = $database_bibles->getChapter ($bible, 19, 11);
-    $this->assertEquals($this->psalms_11_data, $data);
-
-    // New working directory.
-    $newdirectory = uniqid (sys_get_temp_dir(). '/');
-    mkdir ($newdirectory);
-
-    // Call the filter.
-    Filter_Git::bibleDatabase2filedata ($bible, $newdirectory);
-
-    // Compare new directory with the standard one.
-    system ("diff -r $newdirectory $directory", $exit_code);
-    $this->assertEquals(0, $exit_code);
-    
-    // Tear down.
-    $database_bibles->deleteBible ($bible);
-    Filter_Rmdir::rmdir ($directory);
-    Filter_Rmdir::rmdir ($newdirectory);
+    $this->assertFileExists ("$repository/.git");
+    $this->assertFileNotExists ("$repository/Psalms/0/data");
+    $this->assertFileNotExists ("$repository/Psalms/11/data");
+    $this->assertFileNotExists ("$repository/Song of Solomon/2/data");
+    $this->assertFileExists ("$repository/Exodus/1/data");
   }
 
 
+  public function testSyncBibleToGit2 ()
+  {
+    $database_bibles = Database_Bibles::getInstance();
+
+    $repository = $this->repository;
+    
+    $this->assertFileExists ("$repository/.git");
+    $this->assertFileExists ("$repository/Psalms/0/data");
+    $this->assertFileExists ("$repository/Psalms/11/data");
+    $this->assertFileExists ("$repository/Song of Solomon/2/data");
+    $this->assertFileNotExists ("$repository/Exodus/1/data");
+
+    $database_bibles->storeChapter ($this->bible, 19, 1, $this->song_of_solomon_2_data);
+    Filter_Git::syncBible2Git ($this->bible, $this->repository);
+
+    $this->assertFileExists ("$repository/.git");
+    $this->assertFileNotExists ("$repository/Psalms/0/data");
+    $this->assertFileExists ("$repository/Psalms/1/data");
+
+    $data = file_get_contents ("$repository/Psalms/1/data");
+    $this->assertEquals ($this->song_of_solomon_2_data, $data);
+  }
+
+  
+  public function testSyncBibleToGit3 ()
+  {
+    $database_bibles = Database_Bibles::getInstance();
+
+    $repository = $this->repository;
+    
+    $this->assertFileExists ("$repository/.git");
+    $this->assertFileExists ("$repository/Psalms/0/data");
+    $this->assertFileExists ("$repository/Psalms/11/data");
+    $this->assertFileExists ("$repository/Song of Solomon/2/data");
+    $this->assertFileNotExists ("$repository/Exodus/1/data");
+
+    $database_bibles->storeChapter ($this->bible, 19, 1, $this->song_of_solomon_2_data);
+    $database_bibles->storeChapter ($this->bible, 22, 2, $this->psalms_11_data);
+    $database_bibles->storeChapter ($this->bible, 19, 11, $this->song_of_solomon_2_data);
+    Filter_Git::syncBible2Git ($this->bible, $this->repository);
+
+    $this->assertFileExists ("$repository/.git");
+    $this->assertFileExists ("$repository/Song of Solomon/2/data");
+    $this->assertFileExists ("$repository/Psalms/1/data");
+    $this->assertFileExists ("$repository/Song of Solomon/2/data");
+    $this->assertFileExists ("$repository/Psalms/11/data");
+
+    $data = file_get_contents ("$repository/Song of Solomon/2/data");
+    $this->assertEquals ($this->psalms_11_data, $data);
+
+    $data = file_get_contents ("$repository/Psalms/11/data");
+    $this->assertEquals ($this->song_of_solomon_2_data, $data);
+
+    $data = file_get_contents ("$repository/Psalms/1/data");
+    $this->assertEquals ($this->song_of_solomon_2_data, $data);
+  }
+  
+
+  public function testSyncGitToBibleAddChapters ()
+  {
+    $database_bibles = Database_Bibles::getInstance();
+    // The git repository has Psalm 0, Psalm 11, and Song of Solomon 2.
+    // The Bible has been created, but has no data yet.
+    // Run the filter, and check that all three chapters are now the database.
+    Filter_Git::syncGit2Bible ($this->repository, $this->bible);
+    $books = $database_bibles->getBooks ($this->bible);
+    $this->assertEquals ($books, array (19, 22));
+    // Check that the data matches.
+    $usfm = $database_bibles->getChapter ($this->bible, 19, 0);
+    $this->assertEquals ($this->psalms_0_data, $usfm);
+    $usfm = $database_bibles->getChapter ($this->bible, 19, 11);
+    $this->assertEquals ($this->psalms_11_data, $usfm);
+    $usfm = $database_bibles->getChapter ($this->bible, 22, 2);
+    $this->assertEquals ($this->song_of_solomon_2_data, $usfm);
+  }
+
+
+  public function testSyncGitToBibleDeleteChapters ()
+  {
+    // The git repository has Psalm 0, Psalm 11, and Song of Solomon 2.
+    // Put that into the database.
+    $database_bibles = Database_Bibles::getInstance();
+    Filter_Git::syncGit2Bible ($this->repository, $this->bible);
+    // Remove one book and one chapter from the git repository,
+    // and check that after running the filter, the database is updated accordingly.
+    Filter_Rmdir::rmdir ($this->repository . "/Song of Solomon");
+    Filter_Rmdir::rmdir ($this->repository . "/Psalms/0");
+    Filter_Git::syncGit2Bible ($this->repository, $this->bible);
+    $books = $database_bibles->getBooks ($this->bible);
+    $this->assertEquals ($books, array (19));
+    // Check that the data matches.
+    $usfm = $database_bibles->getChapter ($this->bible, 19, 0);
+    $this->assertEquals ("", $usfm);
+    $usfm = $database_bibles->getChapter ($this->bible, 19, 11);
+    $this->assertEquals ($this->psalms_11_data, $usfm);
+    $usfm = $database_bibles->getChapter ($this->bible, 22, 2);
+    $this->assertEquals ("", $usfm);
+  }
+  
+
+  public function testSyncGitToBibleUpdateChapters ()
+  {
+    // The git repository has Psalm 0, Psalm 11, and Song of Solomon 2.
+    // Put that into the database.
+    $database_bibles = Database_Bibles::getInstance();
+    Filter_Git::syncGit2Bible ($this->repository, $this->bible);
+    // Update some chapters in the git repository,
+    // and check that after running the filter, the database is updated accordingly.
+    file_put_contents ($this->repository . "/Psalms/11/data", "\\c 11");
+    file_put_contents ($this->repository . "/Song of Solomon/2/data", "\\c 2");
+    Filter_Git::syncGit2Bible ($this->repository, $this->bible);
+    $usfm = $database_bibles->getChapter ($this->bible, 19, 0);
+    $this->assertEquals ($this->psalms_0_data, $usfm);
+    $usfm = $database_bibles->getChapter ($this->bible, 19, 11);
+    $this->assertEquals ("\\c 11", $usfm);
+    $usfm = $database_bibles->getChapter ($this->bible, 22, 2);
+    $this->assertEquals ("\\c 2", $usfm);
+  }
+  
+
   /**
   * This tests round-tripping consultation notes to the file system.
   * The notes are in the database, get copied to the file system, 
@@ -159,7 +278,6 @@ EOD;
   public function testNotesDatabaseToFileToDatabase()
   {
     $database_notes = Database_Notes::getInstance ();
-    $this->initialize_data ();
     
     // Working directory.
     $directory = uniqid (sys_get_temp_dir() . '/');
@@ -176,7 +294,6 @@ EOD;
     $database_notes->assignUser ($identifier2, "user3");
     $database_notes->subscribeUser ($identifier1, "subscriber1");
     $database_notes->subscribeUser ($identifier1, "subscriber2");
-    $database_notes->setPrivacy ($identifier3, 5);
     
     // Transfer these notes (and other ones that may be in the database) to the file system.
     Filter_Git::notesDatabase2filedata ($directory);
@@ -207,7 +324,6 @@ EOD;
     unset ($contents2[3]); // Remove assignee 'user1';
     $contents2[10] = "40.50.60"; // Update passages.
     $contents3[11] = 10; // Update severity.
-    $contents3[13] = 55; // Update privacy.
     $contents3[15] = "-summary-"; // Update summary.
     
     // Store the new content to file; delete or rename notes.
@@ -244,7 +360,6 @@ EOD;
     $this->assertTrue (in_array ("user3", $database_notes->getAssignees ($identifier2)));
     $this->assertEquals (array (array (40, 50, 60)), $database_notes->getPassages ($identifier2));
     $this->assertEquals (10, $database_notes->getRawSeverity ($identifier3));
-    $this->assertEquals (55, $database_notes->getPrivacy ($identifier3));
     $this->assertEquals ("-summary-", $database_notes->getSummary ($identifier3));
     $this->assertEquals ("bible5", $database_notes->getBible ($identifier6));
     $this->assertEquals ("summary5", $database_notes->getSummary ($identifier6));
@@ -260,43 +375,5 @@ EOD;
   }
 
 
-  /*
-  * Tests the git filter that resolves a conflict.
-  */
-  public function testResolveConflict()
-  {
-$contents = <<<'EOD'
-<<<<<<< HEAD:3 John/1/data
-\v 1 xFrom the church leader.
-=======
-\v 1 xxFrom the church leader.
->>>>>>> a62f843ce41ed2d0325c8a2767993df6acdbc933:3 John/1/data
-EOD;
-    $filename = uniqid (sys_get_temp_dir() . '/');
-    file_put_contents ($filename, $contents);
-    Filter_Git::resolveConflict ($contents, $filename);
-$reference = <<<'EOD'
-\v 1 xxFrom the church leader.
-EOD;
-    $this->assertEquals ($reference, $contents);
-    $contents = file_get_contents ($filename);
-    $this->assertEquals ($reference, $contents);
-
-$contents = <<<'EOD'
-\v 1 xFrom the church leader.
-EOD;
-    file_put_contents ($filename, $contents);
-    Filter_Git::resolveConflict ($contents, NULL);
-$reference = <<<'EOD'
-\v 1 xFrom the church leader.
-EOD;
-    $this->assertEquals ($reference, $contents);
-    $contents = file_get_contents ($filename);
-    $this->assertEquals ($reference, $contents);
-    
-    unlink ($filename);
-  }
-
-
 }
-?>
\ No newline at end of file
+?>
