@@ -1,25 +1,21 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
- ** Copyright (©) 2003-2013 Teus Benschop.
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 3 of the License, or
- ** (at your option) any later version.
- **  
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- ** GNU General Public License for more details.
- **  
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- **  
- */
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 require_once ("../bootstrap/bootstrap.php");
 
@@ -32,10 +28,17 @@ if (php_sapi_name () != "cli") {
   die;
 }
 
+ignore_user_abort (true);
+set_time_limit (0);
+
 $location = $argv[1];
 $bible = $argv[2];
 $database_logs->log ("Importing from location $location into Bible $bible" , true);
 
+$folder = Filter_Archive::uncompress ($file, true);
+if ($folder != NULL) $location = $folder;
+unset ($folder);
+
 $files = array ();
 
 if (is_dir ($location)) {
@@ -55,9 +58,11 @@ $stylesheet = $database_config_user->getStylesheet();
 $database_bibles = Database_Bibles::getInstance();
 $database_snapshots = Database_Snapshots::getInstance();
 $database_books = Database_Books::getInstance ();
+$database_logs = Database_Logs::getInstance ();
+
 
 foreach ($files as $file) {
-  $database_logs->log ("Examining file $file", true);
+  $database_logs->log ("Examining file for import: $file", true);
   $success_message = "";
   $error_message = "";
   $data = file_get_contents ($file);
@@ -73,19 +78,11 @@ foreach ($files as $file) {
             $database_bibles->storeChapter ($bible, $book_number, $chapter_number, $chapter_data);
             $database_snapshots->snapChapter ($bible, $book_number, $chapter_number, $chapter_data, 1);
             $book_name = $database_books->getUsfmFromId ($book_number);
-            $success_message .= " $book_name $chapter_number"; 
+            $database_logs->log ("Imported $book_name $chapter_number", MANAGER_LEVEL); 
           } else {
-            $error_message .= " " . substr ($chapter_data, 0, 1000); 
+            $database_logs->log ("Could not import this data: " . substr ($chapter_data, 0, 1000), MANAGER_LEVEL); 
           }
         }
-        if ($error_message != "") {
-          $error_message = "Could not import this data:" . $error_message;
-          $database_logs->log ($error_message, true);
-        }
-        if ($success_message != "") {
-          $success_message = "The following was imported:" . $success_message;
-          $database_logs->log ($success_message, true);
-        }
       } else {
         $database_logs->log ("The file does not contain valid Unicode UTF-8 text.", true);
       }
@@ -98,4 +95,4 @@ foreach ($files as $file) {
 
 $database_logs->log ("Import Bible data has finished", true);
 
-?>
\ No newline at end of file
+?>
