@@ -1,24 +1,20 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
-** Copyright (©) 2003-2013 Teus Benschop.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 3 of the License, or
-** (at your option) any later version.
-**  
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
-**  
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-**  
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
@@ -32,7 +28,9 @@ function page_access_level ($level)
 {
   $session_logic = Session_Logic::getInstance ();
   if ($level > $session_logic->currentLevel ()) {
-    Assets_Page::header (gettext ("Privileges"));
+    $header = new Assets_Header ("Privileges");
+    $header->setLogin ();
+    $header->run ();
     $view = new Assets_View (__FILE__);
     $view->render ("bootstrap.php");
     Assets_Page::footer ();
