@@ -1,4 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+ 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 require_once ("../bootstrap/bootstrap.php");
@@ -18,7 +35,7 @@ if (isset ($goto)) {
   if ($passage != NULL) {
     $ipc_focus = Ipc_Focus::getInstance();
     $ipc_focus->set ($passage['book'], $passage['chapter'], $passage['verse']);
-    header ("Location: ../desktop/index.php?desktop=edittext");
+    header ("Location: ../editusfm/index.php");
     die;
   } else {
     $view->view->error = gettext ("The passage for this entry was not found.");
