@@ -1,4 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+  
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 class Database_Bibles
@@ -19,6 +36,9 @@ class Database_Bibles
    */
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
+    $database_instance->runQuery ("REPAIR TABLE bible_names;");
+    $database_instance->runQuery ("REPAIR TABLE bible_data;");
+    $database_instance->runQuery ("REPAIR TABLE bible_diff;");
     $database_instance->runQuery ("OPTIMIZE TABLE bible_names;");
     $database_instance->runQuery ("OPTIMIZE TABLE bible_data;");
     $database_instance->runQuery ("OPTIMIZE TABLE bible_diff;");
@@ -326,6 +346,26 @@ class Database_Bibles
   }
       
 
+  /*
+   * Gets the chapter id.
+   */
+  public function getChapterId ($bible, $book, $chapter)
+  {
+    $database_instance = Database_Instance::getInstance();
+    $bible = Database_SQLInjection::no ($bible);
+    if (!is_numeric ($bible)) $bible = $this->getID ($bible);
+    $book = Database_SQLInjection::no ($book);
+    $chapter = Database_SQLInjection::no ($chapter);
+    $query = "SELECT id FROM bible_data WHERE bible = $bible AND book = $book AND chapter = $chapter;";
+    $result = $database_instance->runQuery ($query);
+    if ($result->num_rows > 0) {
+      $row = $result->fetch_row();
+      return $row[0];
+    }
+    return 0;
+  }
+      
+
   /*
    * Returns true if diff data exists for the chapter.
    * Else it returns false.
