@@ -1,4 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 class Database_Config_User
@@ -19,6 +36,7 @@ class Database_Config_User
   */
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
+    $database_instance->runQuery ("REPAIR TABLE config_user;");
     $database_instance->runQuery ("OPTIMIZE TABLE config_user;");
   }
 
@@ -354,6 +372,16 @@ class Database_Config_User
     $this->setValue ("", "pending-changes-notification", $value);
   }   
 
+  public function getUserChangesNotification () {
+    return $this->getValue ("", "user-changes-notification", false);
+  }
+  public function getUserUserChangesNotification ($username) {
+    return $this->getValueForUser ($username, "user-changes-notification", false);
+  }
+  public function setUserChangesNotification ($value) {
+    $this->setValue ("", "user-changes-notification", $value);
+  }   
+
   public function getAssignedNotesStatisticsNotification () {
     return $this->getValue ("", "assigned-notes-statistics-notification", false);
   }
@@ -401,6 +429,37 @@ class Database_Config_User
     $this->setList ("", "active-resources", $values);
   }   
 
+  public function getConsistencyBibles () {
+    return $this->getList ("", "consistency-bibles");
+  }
+  public function setConsistencyBibles ($values) {
+    $this->setList ("", "consistency-bibles", $values);
+  }   
+
+  public function getSprintMonth () {
+    return $this->getValue ("", "sprint-month", date ("n"));
+  }
+  public function setSprintMonth ($value) {
+    $this->setValue ("", "sprint-month", $value);
+  }   
+
+  public function getSprintYear () {
+    return $this->getValue ("", "sprint-year", date ("Y"));
+  }
+  public function setSprintYear ($value) {
+    $this->setValue ("", "sprint-year", $value);
+  }   
+
+  public function getSprintProgressNotification () {
+    return $this->getValue ("", "sprint-progress-notification", false);
+  }
+  public function getUserSprintProgressNotification ($username) {
+    return $this->getValueForUser ($username, "sprint-progress-notification", false);
+  }
+  public function setSprintProgressNotification ($value) {
+    $this->setValue ("", "sprint-progress-notification", $value);
+  }   
+
 }
 
 
