@@ -1,4 +1,22 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
+
 /**
 * Database_Mail
 * Handles mail sent from the translation environment to the users.
@@ -27,6 +45,7 @@ class Database_Mail
   */
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
+    $database_instance->runQuery ("REPAIR TABLE mail;");
     $database_instance->runQuery ("OPTIMIZE TABLE mail;");
   }
 
@@ -138,13 +157,10 @@ class Database_Mail
   }
 
 
-  /**
-  * Removes older entries.
-  */
   public function trim ()
   {
     $database_instance = Database_Instance::getInstance();
-    $time = time () - 7776000; // Remove entries after 90 days.
+    $time = time () - 2592000; // Remove entries after 30 days.
     $query = "DELETE FROM mail WHERE timestamp < $time;";
     $database_instance->runQuery ($query);
   }   
