@@ -1,25 +1,21 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
- ** Copyright (©) 2003-2013 Teus Benschop.
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 3 of the License, or
- ** (at your option) any later version.
- **  
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- ** GNU General Public License for more details.
- **  
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- **  
- */
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 class Database_Notes
@@ -58,8 +54,19 @@ class Database_Notes
   }
 
 
+  public function trim () {
+    $this->touchMarkedForDeletion ();
+    $identifiers = $this->getDueForDeletion ();
+    foreach ($identifiers as $identifier) {
+      $this->delete ($identifier);
+      $this->unmarkForDeletion ($identifier);
+    }
+  }
+
+
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
+    $database_instance->runQuery ("REPAIR TABLE notes;");
     $database_instance->runQuery ("OPTIMIZE TABLE notes;");
   }
 
@@ -127,6 +134,7 @@ class Database_Notes
     $session_logic = Session_Logic::getInstance();
     $user = $session_logic->currentUser ();
     $new_contents .= "<p>$user ($datetime):</p>\n";
+    if ($contents == "<br>") $contents = "";
     $lines = explode ("\n", $contents);
     foreach ($lines as $line) {
       $line = trim ($line);
@@ -154,7 +162,7 @@ class Database_Notes
     $passage = Database_SQLInjection::no ($this->encodePassage ($book, $chapter, $verse));
     // If the $summary is not given, take the first line of the $contents as the $summary.
     if ($summary == "") {
-      // The wysiwyg editor, jsysiwyg, does not put new lines at each line, but instead <div>s. Handle these also.
+      // The notes editor does not put new lines at each line, but instead <div>s. Handle these also.
       $summary = str_replace ("<", "\n", $contents);
       $summary = explode ("\n", $summary);
       $summary = $summary[0];
@@ -163,7 +171,7 @@ class Database_Notes
     if (!$raw) $contents = $this->assembleContents ($identifier, $contents);
     $contents = Database_SQLInjection::no ($contents);
     if (($contents == "") && ($summary == "")) return;
-    $query = "INSERT INTO notes VALUES (NULL, $identifier, 0, '', '', '$bible', '$passage', 'New', 2, 0, '$summary', '$contents', NULL, NULL)";
+    $query = "INSERT INTO notes VALUES (NULL, $identifier, 0, '', '', '$bible', '$passage', 'New', 2, '$summary', '$contents', NULL, NULL)";
     $server->runQuery ($query);
     $this-> updateSearchFields ($identifier);
     $this->noteEditedActions ($identifier);
@@ -185,12 +193,10 @@ class Database_Notes
   * $text_selector: Optionally limits the selection to notes that contains certain text. Used for searching notes.
   * $search_text: Works with $text_selector, contains the text to search for.
   * $limit: If non-NULL, it indicates the starting limit for the selection.
-  * $userlevel: if 0, it takes the user's level from the current user, else it takes the level passed in the variable $userlevel itself.
   */
-  public function selectNotes ($bible, $book, $chapter, $verse, $passage_selector, $edit_selector, $non_edit_selector, $status_selector, $bible_selector, $assignment_selector, $subscription_selector, $severity_selector, $text_selector, $search_text, $limit, $userlevel)
+  public function selectNotes ($bible, $book, $chapter, $verse, $passage_selector, $edit_selector, $non_edit_selector, $status_selector, $bible_selector, $assignment_selector, $subscription_selector, $severity_selector, $text_selector, $search_text, $limit)
   {
     $session_logic = Session_Logic::getInstance ();
-    if ($userlevel == 0)  $userlevel = $session_logic->currentLevel ();
     $username = $session_logic->currentUser ();
     $identifiers = array ();
     $server = Database_Instance::getInstance ();
@@ -202,8 +208,6 @@ class Database_Notes
     }
     // SQL FROM ... WHERE statement.
     $query .= Filter_Sql::notesFromWhereStatement ();
-    // SQL privacy statement.
-    $query .= Filter_Sql::notesConsiderPrivacy ($userlevel);
     // Consider passage selector.
     switch ($passage_selector) {
       case 0:
@@ -402,6 +406,7 @@ class Database_Notes
     $server->runQuery ($query);
     $this->updateSearchFields ($identifier);
     $this->noteEditedActions ($identifier);
+    $this->unmarkForDeletion ($identifier);
   }
   
   
@@ -644,9 +649,6 @@ class Database_Notes
     $query = "UPDATE notes SET bible = '$bible' WHERE identifier = $identifier;";
     $server->runQuery ($query);
     $this->noteEditedActions ($identifier);
-    // Add a comment for the change of Bible.
-    // if ($bible == "") $bible = gettext ("none");
-    // $this->addComment ($identifier, gettext ("The note's Bible was changed to:") . " " . $bible);
   }
 
 
@@ -736,7 +738,6 @@ class Database_Notes
     $server->runQuery ($query);
     if (!$import) {
       $this->noteEditedActions ($identifier);
-      // $this->addComment ($identifier, gettext ("The note's passages were updated"));
     }
   }
 
@@ -855,7 +856,6 @@ class Database_Notes
     $server->runQuery ($query);
     if (!$import) {
       $this->noteEditedActions ($identifier);
-      // $this->addComment ($identifier, gettext ("The note's status was updated"));
     }
   }
 
@@ -936,7 +936,6 @@ class Database_Notes
     $query = "UPDATE notes SET severity = $severity WHERE identifier = $identifier;";
     $server->runQuery ($query);
     $this->noteEditedActions ($identifier);
-    // $this->addComment ($identifier, gettext ("The note's severity was updated"));
   }
 
 
@@ -952,53 +951,6 @@ class Database_Notes
   }
   
 
-  /**
-  * Returns the privacy of a note as a number.
-  */
-  public function getPrivacy ($identifier)
-  {
-    $server = Database_Instance::getInstance ();
-    $identifier = Database_SQLInjection::no ($identifier);
-    $query = "SELECT private FROM notes WHERE identifier = $identifier;";
-    $result = $server->runQuery ($query);
-    $privacy = 0;
-    if ($result->num_rows > 0) {
-      $row = $result->fetch_row();
-      $privacy = $row[0];
-    }
-    return $privacy;
-  }
-
-
-  /**
-  * Sets the $privacy of the note identified by $identifier.
-  * $privacy is a number.
-  */
-  public function setPrivacy ($identifier, $privacy)
-  {
-    $server = Database_Instance::getInstance ();
-    $identifier = Database_SQLInjection::no ($identifier);
-    $privacy = Database_SQLInjection::no ($privacy);
-    $query = "UPDATE notes SET private = $privacy WHERE identifier = $identifier;";
-    $server->runQuery ($query);
-    $this->noteEditedActions ($identifier);
-    // $this->addComment ($identifier, gettext ("The note's privacy was updated"));
-  }
-
-
-  /**
-  * Gets an array with the possible privacy values.
-  */
-  public function getPossiblePrivacies ()
-  {
-    include ("session/levels.php");
-    for ($i = GUEST_LEVEL; $i <= ADMIN_LEVEL; $i++) {
-      $privacies[] = $i;
-    }
-    return $privacies;
-  }
-
-  
   public function getModified ($identifier)
   {
     $server = Database_Instance::getInstance ();
@@ -1110,10 +1062,6 @@ class Database_Notes
     $query .= Filter_Sql::notesOptionalFulltextSearchRelevanceStatement ($search);
     // SQL FROM ... WHERE statement.
     $query .= Filter_Sql::notesFromWhereStatement ();
-    // SQL privacy statement.
-    $session_logic = Session_Logic::getInstance ();
-    $userlevel = $session_logic->currentLevel ();
-    $query .= Filter_Sql::notesConsiderPrivacy ($userlevel);
     // Consider text contained in notes.
     $query .= Filter_Sql::notesOptionalFulltextSearchStatement ($search);
     // Notes get ordered on relevance of search hits.
@@ -1132,6 +1080,60 @@ class Database_Notes
     }
     return $identifiers;
   }
+
+
+  public function markForDeletion ($identifier)
+  {
+    $this->unmarkForDeletion ($identifier);
+    $server = Database_Instance::getInstance ();
+    $identifier = Database_SQLInjection::no ($identifier);
+    // Delete after 7 days.
+    $query = "INSERT INTO notes_del VALUES ($identifier, 7)";
+    $server->runQuery ($query);
+  }
+  
+  
+  public function unmarkForDeletion ($identifier)
+  {
+    $server = Database_Instance::getInstance ();
+    $identifier = Database_SQLInjection::no ($identifier);
+    $query = "DELETE FROM notes_del WHERE note = $identifier;";
+    $result = $server->runQuery ($query);
+  }
+
+
+  public function isMarkedForDeletion ($identifier)
+  {
+    $server = Database_Instance::getInstance ();
+    $identifier = Database_SQLInjection::no ($identifier);
+    $query = "SELECT count(*) FROM notes_del WHERE note = $identifier;";
+    $result = $server->runQuery ($query);
+    $count = $result->fetch_row();
+    $count = $count [0];
+    return ($count > 0);
+  }
+  
+  
+  public function touchMarkedForDeletion ()
+  {
+    $server = Database_Instance::getInstance ();
+    $query = "UPDATE notes_del SET days = days - 1;";
+    $result = $server->runQuery ($query);
+  }
+
+
+  public function getDueForDeletion ()
+  {
+    $server = Database_Instance::getInstance ();
+    $identifiers = array ();
+    $query = "SELECT note FROM notes_del WHERE days <= 0;";
+    $result = $server->runQuery ($query);
+    for ($i = 0; $i < $result->num_rows; $i++) {
+      $row = $result->fetch_row();
+      $identifiers [] = $row[0];
+    }
+    return $identifiers;
+  }
   
   
 }
