@@ -1,6 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
 
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 class Database_Users
@@ -23,6 +38,7 @@ class Database_Users
   public function optimize ()
   {
     $database_instance = Database_Instance::getInstance();
+    $database_instance->runQuery ("REPAIR TABLE users;");
     $database_instance->runQuery ("OPTIMIZE TABLE users;");
   }
   
@@ -258,4 +274,4 @@ class Database_Users
 
 
 
-?>
\ No newline at end of file
+?>
