@@ -1,25 +1,21 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
- ** Copyright (©) 2003-2013 Teus Benschop.
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 3 of the License, or
- ** (at your option) any later version.
- **  
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- ** GNU General Public License for more details.
- **  
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- **  
- */
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 /**
@@ -41,6 +37,8 @@ class Database_Versifications
 
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
+    $database_instance->runQuery ("REPAIR TABLE versification_names;");
+    $database_instance->runQuery ("REPAIR TABLE versification_data;");
     $database_instance->runQuery ("OPTIMIZE TABLE versification_names;");
     $database_instance->runQuery ("OPTIMIZE TABLE versification_data;");
   }
@@ -169,9 +167,7 @@ class Database_Versifications
   }
 
 
-  /**
-    * getBooksChaptersVerses - Returns the books, chapters, verses for the given versification system.
-    */
+  // Returns the books, chapters, verses for the given versification system.
   public function getBooksChaptersVerses ($name)
   {
     $id = $this->getID ($name);
@@ -181,6 +177,61 @@ class Database_Versifications
     return $result;
   }
   
+  
+  public function getBooks ($name)
+  {
+    $id = $this->getID ($name);
+    $query = "SELECT DISTINCT book FROM versification_data WHERE system = $id ORDER BY book ASC;";
+    $database_instance = Database_Instance::getInstance();
+    $result = $database_instance->runQuery ($query);
+    $books = array ();
+    for ($i = 0; $i < $result->num_rows; $i++) {
+      $row = $result->fetch_row();
+      $books [] = $row[0];
+    }
+    return $books;
+  }
+  
+  
+  // This returns all the chapters in $book of versification system $name.
+  // $include0: Includes chapter 0 also.
+  public function getChapters ($name, $book, $include0 = false)
+  {
+    $id = $this->getID ($name);
+    $book = Database_SQLInjection::no ($book);
+    $query = "SELECT DISTINCT chapter FROM versification_data WHERE system = $id AND book = $book ORDER BY chapter ASC;";
+    $database_instance = Database_Instance::getInstance();
+    $result = $database_instance->runQuery ($query);
+    $chapters = array ();
+    if ($include0) $chapters [] = 0;
+    for ($i = 0; $i < $result->num_rows; $i++) {
+      $row = $result->fetch_row();
+      $chapters [] = $row[0];
+    }
+    return $chapters;
+  }
+
+
+  public function getVerses ($name, $book, $chapter)
+  {
+    $id = $this->getID ($name);
+    $book = Database_SQLInjection::no ($book);
+    $chapter = Database_SQLInjection::no ($chapter);
+    $query = "SELECT DISTINCT verse FROM versification_data WHERE system = $id AND book = $book AND chapter = $chapter ORDER BY verse ASC;";
+    $database_instance = Database_Instance::getInstance();
+    $result = $database_instance->runQuery ($query);
+    $verses = array ();
+    if ($result->num_rows > 0) {
+      $row = $result->fetch_row();
+      $verse = $row[0];
+      for ($i = 0; $i <= $verse; $i++) {
+        $verses [] = $i;
+      }
+    }
+    // Put verse 0 in chapter 0.
+    if ($chapter == 0) $verses [] = 0;
+    return $verses;
+  }
 
 
 }
