@@ -1,25 +1,22 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
- ** Copyright (©) 2003-2013 Teus Benschop.
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 3 of the License, or
- ** (at your option) any later version.
- **  
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- ** GNU General Public License for more details.
- **  
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- **  
- */
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+ 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
+
 
 class Filter_Books
 {
@@ -98,6 +95,16 @@ class Filter_Books
       return $identifier;
     }
 
+    // Handle names from BibleWorks when copying the verse list to the clipboard.
+    // These are not handled elsewhere.
+    if ($book == "Cant") return 22;
+    if ($book == "Mk") return 41;
+    if ($book == "Lk") return 42;
+    if ($book == "Jn") return 43;
+    if ($book == "1 Jn") return 62;
+    if ($book == "2 Jn") return 63;
+    if ($book == "3 Jn") return 64;
+
     // Try the abbreviations of the Online Bible.
     $identifier = $database_books->getIdFromOnlinebible ($book);
     if ($identifier) {
@@ -290,6 +297,52 @@ class Filter_Books
   }
 
 
+  /*
+  This deals with sequences and ranges of verses, like the following:
+  Exod. 37:4-5, 14-15, 27-28
+  It puts each verse on a separate line.
+  */
+  static public function handleSequencesRanges ($passage)
+  {
+    // A passage like Exod. 37:4-5, 14-15, 27-28 will be cut at the comma.
+    // The resulting array contains the following:
+    // Exod. 37:4-5
+    // 14-15
+    // 27-28
+    // It implies that the first sequence has book and chapter.
+    $sequences = explode (",", $passage);
+    foreach ($sequences as &$line) $line = trim ($line);
+    unset ($line);
+
+    // Store output lines.
+    $output = array ();
+
+    // Cut the passages at the hyphen.
+    foreach ($sequences as $offset => $sequence) {
+      $range = explode ("-", $sequence);
+      if (count ($range) == 1) {
+        $output [] = trim ($range [0]);
+      } else {
+        $start = trim ($range [0]);
+        $output [] = $start;
+        if ($offset == 0) {
+          // Since the first bit contains book / chapter / verse,
+          // extract the verse number.
+          $start = strrev ($start);
+          $start = Filter_Numeric::integer_in_string ($start);
+          $start = strrev ($start);
+        }
+        $end = trim ($range [1]);
+        for ($i = $start + 1; $i <= $end; $i++) {
+          $output [] = $i;
+        }
+      }
+    }
+    
+    // Result.
+    return $output;
+  }
+
 
 }
 
