@@ -1,25 +1,22 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
- ** Copyright (©) 2003-2013 Teus Benschop.
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 3 of the License, or
- ** (at your option) any later version.
- **  
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- ** GNU General Public License for more details.
- **  
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- **  
- */
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+ 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
+
 
 class Filter_Datetime
 {
@@ -28,11 +25,7 @@ class Filter_Datetime
   */
   public static function timezones ()
   {
-    if (version_compare(PHP_VERSION, '5.2.0', '>=')) {
-      $identifiers = DateTimeZone::listIdentifiers();
-    } else {
-      $identifiers = array ();
-    }
+    $identifiers = DateTimeZone::listIdentifiers();
     sort ($identifiers);
     foreach ($identifiers as $identifier) {
       // Keep the preferred identifiers, and drop the deprecated ones.
@@ -66,6 +59,28 @@ class Filter_Datetime
       $datetime->setTimezone ($datetimezone);
     }
   }
+  
+  
+  public static function isFirstWorkingDayOfMonth ($monthday, $weekday)
+  {
+    if (($monthday == 1) && in_array ($weekday, array (1, 2, 3, 4, 5))) return true;
+    if (in_array ($monthday, array (2, 3)) && ($weekday == 1)) return true;
+    return false;
+  }
+  
+  
+  public static function getLastBusinessDayOfMonth ($year, $month)
+  {
+    $time = mktime (0, 0, 0, $month, 1, $year);
+    $lastday = date ("t", $time);
+    $time = mktime (0, 0, 0, $month, $lastday, $year);
+    $lastweekday = date ("w", $time);
+    if ($lastweekday == 0) $lastday -= 2;
+    if ($lastweekday == 6) $lastday--;
+    return $lastday;
+  }
+ 
+  
 }
 
-?>
\ No newline at end of file
+?>
