@@ -1,25 +1,21 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
- ** Copyright (©) 2003-2013 Teus Benschop.
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 3 of the License, or
- ** (at your option) any later version.
- **  
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- ** GNU General Public License for more details.
- **  
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- **  
- */
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+ 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 class Filter_Usfm
@@ -229,9 +225,8 @@ class Filter_Usfm
     return $verse_numbers;
   }
 
-  /**
-  * Returns the verse number in the string of $usfm code at line number $line_number.
-  */
+
+  // Returns the verse number in the string of $usfm code at line number $line_number.
   public static function lineNumber2VerseNumber ($usfm, $line_number)
   {
     $verse_number = 0; // Initial verse number.
@@ -247,9 +242,47 @@ class Filter_Usfm
     return $verse_number;
   }
 
-  /**
-  * Returns the verse text given a $verse_number and $usfm code.
-  */
+
+  // Returns the verse number in the string of $usfm code at offset $offset.
+  // Offset is calculated with mb_strlen to support UTF-8.
+  public static function offset2verseNumber ($usfm, $offset)
+  {
+    $totalOffset = 0;
+    $lines = explode ("\n", $usfm);
+    foreach ($lines as $lineNumber => $line) {
+      $totalOffset += mb_strlen ($line);
+      if ($totalOffset >= $offset) {
+        return Filter_Usfm::lineNumber2VerseNumber ($usfm, $lineNumber);
+      }
+      // Add 1 for new line.
+      $totalOffset += 1; 
+    }
+    return 0;
+  }
+  
+  
+  // Returns the offset within the $usfm code where $verse number starts.
+  public static function verseNumber2offset ($usfm, $verse)
+  {
+    // Verse number 0 starts at offset 0.
+    if ($verse == 0) return 0;
+    $totalOffset = 0;
+    $lines = explode ("\n", $usfm);
+    foreach ($lines as $line) {
+      $verses = Filter_Usfm::getVerseNumbers ($line);
+      @$v = $verses [1];
+      if ($v == $verse) {
+        return $totalOffset;
+      }
+      $totalOffset += mb_strlen ($line);
+      // Add 1 for new line.
+      $totalOffset += 1; 
+    }
+    return mb_strlen ($usfm);
+  }
+  
+  
+  // Returns the verse text given a $verse_number and $usfm code.
   public static function getVerseText ($usfm, $verse_number)
   {
     // The start of the requested verse number.
