@@ -1,25 +1,21 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
- ** Copyright (©) 2003-2013 Teus Benschop.
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 3 of the License, or
- ** (at your option) any later version.
- **  
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- ** GNU General Public License for more details.
- **  
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- **  
- */
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 class Notes_Logic
@@ -32,10 +28,11 @@ class Notes_Logic
   } 
 
 
-  const notifyNoteNew     = 1;
-  const notifyNoteComment = 2;
-  const notifyNoteUpdate  = 3;
-  const notifyNoteDelete  = 4;
+  const notifyNoteNew             = 1;
+  const notifyNoteComment         = 2;
+  const notifyNoteUpdate          = 3;
+  const notifyNoteDelete          = 4;
+  const notifyMarkNoteForDeletion = 5;
 
 
   public static function getInstance() 
@@ -64,11 +61,13 @@ class Notes_Logic
     }
   }
 
+
   public function handlerUpdateNote ($identifier)
   {
     $this->notifyUsers ($identifier, self::notifyNoteUpdate);
   }
 
+
   public function handlerAssignNote ($identifier, $user)
   {
     $database_config_user = Database_Config_User::getInstance ();
@@ -83,6 +82,12 @@ class Notes_Logic
   }
 
 
+  public function handlerMarkNoteForDeletion ($identifier)
+  {
+    $this->notifyUsers ($identifier, self::notifyMarkNoteForDeletion);
+  }
+
+
   public function handlerDeleteNote ($identifier)
   {
     $this->notifyUsers ($identifier, self::notifyNoteDelete);
@@ -100,22 +105,29 @@ class Notes_Logic
     $database_notes = Database_Notes::getInstance();
     $database_config_user = Database_Config_User::getInstance ();
     $database_users = Database_Users::getInstance();
-    
-    // Whether current user gets subscribed to the note.
-    if ($database_config_user->getSubscribeToConsultationNotesEditedByMe ()) {
-      $database_notes = Database_Notes::getInstance();
-      $database_notes->subscribe ($identifier);
-    }
-    
-    // Users to get subscribed to the note, or to whom the note is to be assigned.
-    $users = $database_users->getUsers ();
-    foreach ($users as $user) {
-      if ($database_config_user->getNotifyUserOfAnyConsultationNotesEdits ($user)) {
-        $database_notes->subscribeUser ($identifier, $user);
+
+    // Subscription and assignment not to be used for notes marked for deletion,
+    // because marking notes for deletion is nearly the same as deleting them 
+    // straightaway.
+    if ($notification != self::notifyMarkNoteForDeletion) {
+
+      // Whether current user gets subscribed to the note.
+      if ($database_config_user->getSubscribeToConsultationNotesEditedByMe ()) {
+        $database_notes = Database_Notes::getInstance();
+        $database_notes->subscribe ($identifier);
       }
-      if ($database_config_user->getUserAssignedToConsultationNotesChanges ($user)) {
-        $database_notes->assignUser ($identifier, $user, false); // Do not add a comment for this automatic assignment.
+    
+      // Users to get subscribed to the note, or to whom the note is to be assigned.
+      $users = $database_users->getUsers ();
+      foreach ($users as $user) {
+        if ($database_config_user->getNotifyUserOfAnyConsultationNotesEdits ($user)) {
+          $database_notes->subscribeUser ($identifier, $user);
+        }
+        if ($database_config_user->getUserAssignedToConsultationNotesChanges ($user)) {
+          $database_notes->assignUser ($identifier, $user, false); // Do not add a comment for this automatic assignment.
+        }
       }
+
     }
 
     // The recipients who receive a notification by email.
@@ -137,8 +149,9 @@ class Notes_Logic
       }
     }
 
-    // In case the consultation note is deleted, notify only the users with this specific notification set.
-    if ($notification == self::notifyNoteDelete) {
+    // In case the consultation note is deleted or marked for deletion,
+    // notify only the users with this specific notification set.
+    if (($notification == self::notifyNoteDelete) || ($notification == self::notifyMarkNoteForDeletion)) {
       $recipients = array ();
       $users = $database_users->getUsers ();
       foreach ($users as $user) {
@@ -161,10 +174,11 @@ class Notes_Logic
     // Generate the label prefixed to the subject line of the email.
     $label = gettext ("General");
     switch ($notification) {
-      case self::notifyNoteNew     : $label = gettext ("New");     break;
-      case self::notifyNoteComment : $label = gettext ("Comment"); break;
-      case self::notifyNoteUpdate  : $label = gettext ("Updated"); break;
-      case self::notifyNoteDelete  : $label = gettext ("Deleted"); break;
+      case self::notifyNoteNew             : $label = gettext ("New");                 break;
+      case self::notifyNoteComment         : $label = gettext ("Comment");             break;
+      case self::notifyNoteUpdate          : $label = gettext ("Updated");             break;
+      case self::notifyNoteDelete          : $label = gettext ("Deleted");             break;
+      case self::notifyMarkNoteForDeletion : $label = gettext ("Marked for deletion"); break;
     }
     
     // Send mail to all recipients.
@@ -194,7 +208,7 @@ class Notes_Logic
     // Include a link to the note on the site.
     $contents .= "<br>\n";
     $siteUrl = $database_config_general->getSiteURL ();
-    $link = "$siteUrl/consultations/notes.php?consultationnote=$identifier";
+    $link = "$siteUrl/notes/note.php?id=$identifier";
     $contents .= "<p><a href=\"$link\">View or respond online</a></p>\n";
     $mailto = "mailto:" . $database_config_general->getSiteMailAddress () . "?subject=(CNID$identifier)";
     $contents .= "<p><a href=\"$mailto\">Respond by email</a></p>\n";
@@ -203,7 +217,6 @@ class Notes_Logic
     }
   }
   
-  
 
   /**
   * handleEmailComment - handles an email received from $from with subject $subject and body $body.
@@ -350,7 +363,7 @@ class Notes_Logic
     return true;
   }
   
-
+  
 }  
 
 
