@@ -1,25 +1,21 @@
 <?php
-/**
-* @package bibledit
-*/
 /*
- ** Copyright (©) 2003-2013 Teus Benschop.
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 3 of the License, or
- ** (at your option) any later version.
- **  
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- ** GNU General Public License for more details.
- **  
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- **  
- */
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+ 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 require_once ("../bootstrap/bootstrap.php");
@@ -92,13 +88,13 @@ if (($minute % 5) == 0) {
 // On a production website running on an inexpensive virtual private server 
 // with 512 Mbyte of memory and a fast network connection, 
 // sending and receiving two Bibles takes more than 15 minutes when there are many changes.
-if (($current_timestamp >= $config_general->getTimerSendReceive ()) || (($hour == 0) && ($minute == 0))) {
-  $config_general->setTimerSendReceive ($current_timestamp + 100000);
-  $workingdirectory = escapeshellarg (dirname (__FILE__));
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::sendreceive);
-  $command = "cd $workingdirectory; php sendreceive.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+$sendreceive = false;
+if (($hour == 0) && ($minute == 0)) $sendreceive = true;
+if ((($minute % 5) == 0) && $config_general->getRepeatSendReceive ()) $sendreceive = true;
+if ($sendreceive) {
+  if (!SendReceive_Logic::isRunning ()) {
+    SendReceive_Logic::start ();
+  }
 }
 
 
@@ -114,9 +110,19 @@ if (($current_timestamp >= $config_general->getTimerDiff ()) || (($hour == 0) &&
 }
 
 
+// Deal with the changes in the Bible made per user.
+if (($hour == 0) && ($minute == 25)) {
+  $workingdirectory = escapeshellarg (dirname (__FILE__));
+  $logfilename = $timer_logger->getLogFilename (Timer_Logger::userchanges);
+  $command = "cd $workingdirectory; php userchanges.php > $logfilename 2>&1 & echo $!";
+  $pid = shell_exec ($command);
+  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+}
+
+
 // Run the checks on the Bibles.
 // This takes 15 minutes on a production machine with two Bibles.
-if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0) && ($minute == 25))) {
+if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0) && ($minute == 30))) {
   $config_general->setTimerChecks ($current_timestamp + 100000);
   $workingdirectory = dirname (__FILE__);
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::checks);
@@ -128,7 +134,7 @@ if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0)
 
 // Database maintenance and trimming.
 // It takes a few minutes on a production machine..
-if (($hour == 0) && ($minute == 40)) {
+if (($hour == 0) && ($minute == 50)) {
   $workingdirectory = dirname (__FILE__);
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::database);
   $command = "cd $workingdirectory; php database.php > $logfilename 2>&1 & echo $!";
@@ -139,7 +145,7 @@ if (($hour == 0) && ($minute == 40)) {
 
 // Create a backup, so that the backup contains the most recent information
 // after the previous tasks have been done.
-if (($current_timestamp >= $config_general->getTimerBackup ()) || (($hour == 0) && ($minute == 45))) {
+if (($current_timestamp >= $config_general->getTimerBackup ()) || (($hour == 0) && ($minute == 55))) {
   $config_general->setTimerBackup ($current_timestamp + 100000);
   $workingdirectory = dirname (__FILE__);
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::backup);
@@ -150,7 +156,7 @@ if (($current_timestamp >= $config_general->getTimerBackup ()) || (($hour == 0)
 
 
 // Email statistics to the users.
-if (($hour == 0) && ($minute == 50)) {
+if (($hour == 1) && ($minute == 0)) {
   $workingdirectory = escapeshellarg (dirname (__FILE__));
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::statistics);
   $command = "cd $workingdirectory; php statistics.php > $logfilename 2>&1 & echo $!";
@@ -159,9 +165,23 @@ if (($hour == 0) && ($minute == 50)) {
 }
 
 
+// Sprint burndown.
+// It runs at midnight, but also in the morning and afternoon.
+// The script itself determines what to do at various times of the day,
+// or days of the week or month.
+$burndown = false;
+if (($hour == 1) && ($minute == 5)) $burndown = true;
+if (($hour == 10) && ($minute == 0)) $burndown = true;
+if (($hour == 14) && ($minute == 0)) $burndown = true;
+if ($burndown) {
+  Sprint_Logic::burndown (false);
+}
+unset ($burndown);
+
+
 // Export the Bibles to the various output formats.
 // This may take an hour on a production machine.
-if (($current_timestamp >= $config_general->getTimerExports ()) || (($hour == 0) && ($minute == 55))) {
+if (($current_timestamp >= $config_general->getTimerExports ()) || (($hour == 1) && ($minute == 10))) {
   $config_general->setTimerExports ($current_timestamp + 100000);
   $workingdirectory = escapeshellarg (dirname (__FILE__));
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::exports);
@@ -171,4 +191,14 @@ if (($current_timestamp >= $config_general->getTimerExports ()) || (($hour == 0)
 }
 
 
+// Clear the past sessions.
+if (($hour == 2) && ($minute == 0)) {
+  $sessions_path = dirname (__FILE__) . "/../session";
+  $logfilename = $timer_logger->getLogFilename (Timer_Logger::sessions);
+  $command = "php sessions.php $sessions_path > $logfilename 2>&1 & echo $!";
+  $pid = shell_exec ($command);
+  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+}
+
+
 ?>
