@@ -1,4 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (MEMBER_LEVEL);
 Assets_Page::header (gettext ("Notifications"));
@@ -71,11 +88,21 @@ if (isset ($_GET['pendingchangenotificationstoggle'])) {
 }
 $view->view->pending_changes_notifications = $database_config_user->getPendingChangesNotification ();
 
+if (isset ($_GET['userchangesnotificationstoggle'])) {
+  $database_config_user->setUserChangesNotification (!$database_config_user->getUserChangesNotification ());
+}
+$view->view->user_changes_notifications = $database_config_user->getUserChangesNotification ();
+
 if (isset ($_GET['biblechecksnotificationtoggle'])) {
   $database_config_user->setBibleChecksNotification (!$database_config_user->getBibleChecksNotification ());
 }
 $view->view->bible_checks_notification = $database_config_user->getBibleChecksNotification ();
 
+if (isset ($_GET['sprintprogressnotificationtoggle'])) {
+  $database_config_user->setSprintProgressNotification (!$database_config_user->getSprintProgressNotification ());
+}
+$view->view->sprint_progress_notification = $database_config_user->getSprintProgressNotification ();
+
 $view->render ("notifications.php");
 Assets_Page::footer ();
 ?>
